@@ -10,17 +10,30 @@ into Python library to avoid complains about missing options, but it is hard
 to invent something more intuitive (like 'fetch').
 """
 
-import sys, urllib, shutil, os
+import sys, urllib, shutil, os, urlparse
+
+
+version = "0.2"
 
 
 if len(sys.argv) < 2:
     sys.exit("No download URL specified")
 
+url = sys.argv[1]
 
-(filename, headers) = urllib.urlretrieve(sys.argv[1])
-# copy filename, because it will be destroyed on exit
-shutil.copy(filename, ".")
-os.unlink(filename)
+def filename_from_url(url):
+    """return detected filename or None"""
+    fname = os.path.basename(urlparse.urlparse(url).path)
+    if len(fname.strip(" \n\t.")) == 0:
+        return None
+    return fname
+                 
+filename = filename_from_url(url) or "."
+
+(tmpfile, headers) = urllib.urlretrieve(url)
+# copy tmpfile, because it will be destroyed on exit
+shutil.copy(tmpfile, filename)
+os.unlink(tmpfile)
 
 
 print headers
@@ -28,9 +41,11 @@ print "Saved under %s" % os.path.basename(filename)
 
 """
 features that require more tuits for urlretrieve API
-http://www.python.org/doc/2.6.4/library/urllib.html#urllib.urlretrieve
+http://www.python.org/2.6/library/urllib.html#urllib.urlretrieve
 
-[ ] autodetect filename for saving file (from URL, from headers)
+[x] autodetect filename from URL
+[ ] autodetect filename from headers - Content-Disposition
+    http://greenbytes.de/tech/tc2231/
 [ ] catch KeyboardInterrupt
 [ ] optionally preserve incomplete file and notify about its location
 [ ] start downloading directly into current directory to save incomplete file
@@ -38,4 +53,5 @@ http://www.python.org/doc/2.6.4/library/urllib.html#urllib.urlretrieve
 [ ] resume download (incomplete file)
 [ ] show progress indicator
     http://mail.python.org/pipermail/tutor/2005-May/038797.html
+[ ] do not overwrite downloaded file
 """
